summaryrefslogtreecommitdiffstats
path: root/.travis/macos
diff options
context:
space:
mode:
authorMerryMage <MerryMage@users.noreply.github.com>2018-01-13 22:37:06 +0100
committerMerryMage <MerryMage@users.noreply.github.com>2018-01-13 23:38:47 +0100
commitf95789a0b3f881a17d854534244ad380389d0cb1 (patch)
tree25e233f7fb4624e7b0d62a5b64534f766e4e3f02 /.travis/macos
parentyuzu: Update CONTRIBUTING.md. (diff)
downloadyuzu-f95789a0b3f881a17d854534244ad380389d0cb1.tar
yuzu-f95789a0b3f881a17d854534244ad380389d0cb1.tar.gz
yuzu-f95789a0b3f881a17d854534244ad380389d0cb1.tar.bz2
yuzu-f95789a0b3f881a17d854534244ad380389d0cb1.tar.lz
yuzu-f95789a0b3f881a17d854534244ad380389d0cb1.tar.xz
yuzu-f95789a0b3f881a17d854534244ad380389d0cb1.tar.zst
yuzu-f95789a0b3f881a17d854534244ad380389d0cb1.zip
Diffstat (limited to '.travis/macos')
-rwxr-xr-x.travis/macos/build.sh2
-rwxr-xr-x.travis/macos/deps.sh8
-rwxr-xr-x.travis/macos/upload.sh44
3 files changed, 31 insertions, 23 deletions
diff --git a/.travis/macos/build.sh b/.travis/macos/build.sh
index c957cdf21..e1c54af55 100755
--- a/.travis/macos/build.sh
+++ b/.travis/macos/build.sh
@@ -4,8 +4,10 @@ set -o pipefail
export MACOSX_DEPLOYMENT_TARGET=10.9
export Qt5_DIR=$(brew --prefix)/opt/qt5
+export UNICORNDIR=$(pwd)/externals/unicorn
mkdir build && cd build
+cmake --version
cmake .. -DUSE_SYSTEM_CURL=ON -DCMAKE_OSX_ARCHITECTURES="x86_64;x86_64h" -DCMAKE_BUILD_TYPE=Release
make -j4
diff --git a/.travis/macos/deps.sh b/.travis/macos/deps.sh
index 30ec99b62..7dea80438 100755
--- a/.travis/macos/deps.sh
+++ b/.travis/macos/deps.sh
@@ -1,4 +1,10 @@
#!/bin/sh -ex
brew update
-brew install qt5 sdl2 dylibbundler p7zip
+brew install dylibbundler p7zip qt5 sdl2
+
+mkdir externals/unicorn
+pushd externals/unicorn
+git clone https://github.com/yuzu-emu/unicorn .
+UNICORN_ARCHS=aarch64 ./make.sh macos-universal-no
+popd
diff --git a/.travis/macos/upload.sh b/.travis/macos/upload.sh
index 19c80fdf0..de0ba91f1 100755
--- a/.travis/macos/upload.sh
+++ b/.travis/macos/upload.sh
@@ -2,22 +2,22 @@
. .travis/common/pre-upload.sh
-REV_NAME="citra-osx-${GITDATE}-${GITREV}"
+REV_NAME="yuzu-osx-${GITDATE}-${GITREV}"
ARCHIVE_NAME="${REV_NAME}.tar.gz"
COMPRESSION_FLAGS="-czvf"
mkdir "$REV_NAME"
-cp build/src/citra/citra "$REV_NAME"
-cp -r build/src/citra_qt/citra-qt.app "$REV_NAME"
+cp build/src/yuzu_cmd/yuzu-cmd "$REV_NAME"
+cp -r build/src/yuzu/yuzu.app "$REV_NAME"
# move qt libs into app bundle for deployment
-$(brew --prefix)/opt/qt5/bin/macdeployqt "${REV_NAME}/citra-qt.app"
+$(brew --prefix)/opt/qt5/bin/macdeployqt "${REV_NAME}/yuzu.app"
# move SDL2 libs into folder for deployment
-dylibbundler -b -x "${REV_NAME}/citra" -cd -d "${REV_NAME}/libs" -p "@executable_path/libs/"
+dylibbundler -b -x "${REV_NAME}/yuzu-cmd" -cd -d "${REV_NAME}/libs" -p "@executable_path/libs/"
-# Make the changes to make the citra-qt app standalone (i.e. not dependent on the current brew installation).
+# Make the changes to make the yuzu app standalone (i.e. not dependent on the current brew installation).
# To do this, the absolute references to each and every QT framework must be re-written to point to the local frameworks
# (in the Contents/Frameworks folder).
# The "install_name_tool" is used to do so.
@@ -33,8 +33,8 @@ QT_BREWS_PATH=$(grealpath "$(brew --prefix qt5)")
BREW_PATH=$(brew --prefix)
QT_VERSION_NUM=5
-$BREW_PATH/opt/qt5/bin/macdeployqt "${REV_NAME_ALT}citra-qt.app" \
- -executable="${REV_NAME_ALT}citra-qt.app/Contents/MacOS/citra-qt"
+$BREW_PATH/opt/qt5/bin/macdeployqt "${REV_NAME_ALT}yuzu.app" \
+ -executable="${REV_NAME_ALT}yuzu.app/Contents/MacOS/yuzu"
# These are the files that macdeployqt packed into Contents/Frameworks/ - we don't want those, so we replace them.
declare -a macos_libs=("QtCore" "QtWidgets" "QtGui" "QtOpenGL" "QtPrintSupport")
@@ -43,7 +43,7 @@ for macos_lib in "${macos_libs[@]}"
do
SC_FRAMEWORK_PART=$macos_lib.framework/Versions/$QT_VERSION_NUM/$macos_lib
# Replace macdeployqt versions of the Frameworks with our own (from /usr/local/opt/qt5/lib/)
- cp "$BREW_PATH/opt/qt5/lib/$SC_FRAMEWORK_PART" "${REV_NAME_ALT}citra-qt.app/Contents/Frameworks/$SC_FRAMEWORK_PART"
+ cp "$BREW_PATH/opt/qt5/lib/$SC_FRAMEWORK_PART" "${REV_NAME_ALT}yuzu.app/Contents/Frameworks/$SC_FRAMEWORK_PART"
# Replace references within the embedded Framework files with "internal" versions.
for macos_lib2 in "${macos_libs[@]}"
@@ -55,11 +55,11 @@ do
install_name_tool -change \
$QT_BREWS_PATH/lib/$RM_FRAMEWORK_PART \
@executable_path/../Frameworks/$RM_FRAMEWORK_PART \
- "${REV_NAME_ALT}citra-qt.app/Contents/Frameworks/$SC_FRAMEWORK_PART"
+ "${REV_NAME_ALT}yuzu.app/Contents/Frameworks/$SC_FRAMEWORK_PART"
install_name_tool -change \
"$BREW_PATH/opt/qt5/lib/$RM_FRAMEWORK_PART" \
@executable_path/../Frameworks/$RM_FRAMEWORK_PART \
- "${REV_NAME_ALT}citra-qt.app/Contents/Frameworks/$SC_FRAMEWORK_PART"
+ "${REV_NAME_ALT}yuzu.app/Contents/Frameworks/$SC_FRAMEWORK_PART"
done
done
@@ -71,40 +71,40 @@ declare -a macos_plugins=("Plugins/platforms/libqcocoa.dylib")
for macos_lib in "${macos_plugins[@]}"
do
- install_name_tool -id @executable_path/../$macos_lib "${REV_NAME_ALT}citra-qt.app/Contents/$macos_lib"
+ install_name_tool -id @executable_path/../$macos_lib "${REV_NAME_ALT}yuzu.app/Contents/$macos_lib"
for macos_lib2 in "${macos_libs[@]}"
do
RM_FRAMEWORK_PART=$macos_lib2.framework/Versions/$QT_VERSION_NUM/$macos_lib2
install_name_tool -change \
$QT_BREWS_PATH/lib/$RM_FRAMEWORK_PART \
@executable_path/../Frameworks/$RM_FRAMEWORK_PART \
- "${REV_NAME_ALT}citra-qt.app/Contents/$macos_lib"
+ "${REV_NAME_ALT}yuzu.app/Contents/$macos_lib"
install_name_tool -change \
"$BREW_PATH/opt/qt5/lib/$RM_FRAMEWORK_PART" \
@executable_path/../Frameworks/$RM_FRAMEWORK_PART \
- "${REV_NAME_ALT}citra-qt.app/Contents/$macos_lib"
+ "${REV_NAME_ALT}yuzu.app/Contents/$macos_lib"
done
done
for macos_lib in "${macos_libs[@]}"
do
# Debugging info for Travis-CI
- otool -L "${REV_NAME_ALT}citra-qt.app/Contents/Frameworks/$macos_lib.framework/Versions/$QT_VERSION_NUM/$macos_lib"
+ otool -L "${REV_NAME_ALT}yuzu.app/Contents/Frameworks/$macos_lib.framework/Versions/$QT_VERSION_NUM/$macos_lib"
done
# Make the citra-qt.app application launch a debugging terminal.
# Store away the actual binary
-mv ${REV_NAME_ALT}citra-qt.app/Contents/MacOS/citra-qt ${REV_NAME_ALT}citra-qt.app/Contents/MacOS/citra-qt-bin
+mv ${REV_NAME_ALT}yuzu.app/Contents/MacOS/yuzu ${REV_NAME_ALT}yuzu.app/Contents/MacOS/yuzu-bin
-cat > ${REV_NAME_ALT}citra-qt.app/Contents/MacOS/citra-qt <<EOL
+cat > ${REV_NAME_ALT}yuzu.app/Contents/MacOS/yuzu <<EOL
#!/usr/bin/env bash
cd "\`dirname "\$0"\`"
-chmod +x citra-qt-bin
-open citra-qt-bin --args "\$@"
+chmod +x yuzu-bin
+open yuzu-bin --args "\$@"
EOL
# Content that will serve as the launching script for citra (within the .app folder)
# Make the launching script executable
-chmod +x ${REV_NAME_ALT}citra-qt.app/Contents/MacOS/citra-qt
+chmod +x ${REV_NAME_ALT}yuzu.app/Contents/MacOS/yuzu
. .travis/common/post-upload.sh
@@ -71,40 +71,40 @@ declare -a macos_plugins=("Plugins/platforms/libqcocoa.dylib")
done
-# Make the citra-qt.app application launch a debugging terminal.
+# Make the yuzu.app application launch a debugging terminal.
# Store away the actual binary
@@ -71,40 +71,40 @@ declare -a macos_plugins=("Plugins/platforms/libqcocoa.dylib")
EOL
-# Content that will serve as the launching script for citra (within the .app folder)
+# Content that will serve as the launching script for yuzu (within the .app folder)
# Make the launching script executable